@@ -4,6 +4,8 @@ Keytotext converts a list of Keywords to sentences and larger texts
 """
 
 
-__version__ = "0.1.4"
+__version__ = "0.1.5"
 
 from .pipeline import pipeline
+from .eval import eval_pipeline
+from .trainer import trainer
